@@ -15,7 +15,7 @@ use Scalar::Util qw/ blessed refaddr /;
 
 use overload ();
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 
 my %Cache;
@@ -38,23 +38,45 @@ sub new {
 
     my $base = Package::Stash->new($name);
 
+    my $_make_symbol = sub {
+        my ($value) = @_;
+        my $self = bless \$value, "${name}::${value}";
+        Internals::SvREADONLY($value, 1);
+        return $self;
+    };
+
     $base->add_symbol(
         '&new',
         sub {
             my ( $class, $value ) = @_;
             state $symbols = {
                 map {
-                    $_ => do {
-                        my $value = $_;
-                        bless \$value, "${name}::${value}";
-                    }
+                    $_ => $_make_symbol->($_)
                 } @values
             };
-            my $self = $symbols->{"$value"} or die "invalid value: '$value'";
-            return $self;
+            exists $symbols->{"$value"} or die "invalid value: '$value'";
+            return $symbols->{"$value"};
         }
     );
 
+    $base->add_symbol( '&values', sub { return @values });
+
+    $name->overload::OVERLOAD(
+        q{""} => sub { my ($self) = @_; return $$self; },
+        q{eq} => sub {
+            my ( $self, $arg ) = @_;
+            return blessed($arg)
+              ? refaddr($arg) == refaddr($self)
+              : $arg eq $$self;
+        },
+        q{ne} => sub {
+            my ( $self, $arg ) = @_;
+            return blessed($arg)
+              ? refaddr($arg) != refaddr($self)
+              : $arg ne $$self;
+        },
+    );
+
     for my $value (@values) {
         my $method = '&is_' . $value;
         $base->add_symbol( $method, sub { '' } );
@@ -62,22 +84,6 @@ sub new {
         my $subtype = Package::Stash->new($elem);
         $subtype->add_symbol( '@ISA',  [$name] );
         $subtype->add_symbol( $method, sub { 1 } );
-
-        $elem->overload::OVERLOAD(
-            q{""} => sub { $value },
-            q{eq} => sub {
-                my ( $self, $arg ) = @_;
-                return blessed($arg)
-                  ? refaddr($arg) == refaddr($self)
-                  : $arg eq $value;
-            },
-            q{ne} => sub {
-                my ( $self, $arg ) = @_;
-                return blessed($arg)
-                  ? refaddr($arg) != refaddr($self)
-                  : $arg ne $value;
-            },
-        );
     }
 
     return $Cache{$key} = $name;
@@ -98,7 +104,7 @@ Data::Enum - fast, immutable enumeration classes
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -181,12 +187,25 @@ Each instance will have an C<is_> method for each value.
 
 Each instance stringifies to its value.
 
+=head2 values
+
+  my @values = $class->values;
+
+Returns a list of valid values, stringified and sorted with duplicates
+removed.
+
+This was added in v0.2.0.
+
 =head1 SEE ALSO
 
 L<Class::Enum>
 
 L<Object::Enum>
 
+L<MooX::Enumeration>
+
+L<MooseX::Enumeration>
+
 L<Type::Tiny::Enum>
 
 =head1 SOURCE
